#ifndef _PGSQL_COMPAT_H

#if USE_VERSION < 73
#define WARNING NOTICE
#endif

#endif /* _PGSQL_COMPAT_H */
